@@ -7,9 +7,8 @@
     :copyright: 2009 by Ronny Pfannschmidt
 """
 
+import py
 from anyvc.util import cachedproperty
-from anyvc.common.repository import Repository
-from anyvc.common.workdir import WorkDir, WorkDirWithParser, CommandBased
 
 class Backend(object):
     def __init__(self, name, module_name):
@@ -17,7 +16,7 @@ class Backend(object):
         self.module_name = module_name
 
     def __repr__(self):
-        return '<anyvc backend %s>'%(self.name,)
+        return '<anyvc backend %s>' % (self.name,)
 
     def _import(self, name):
         module, attr = name.split(':')
@@ -45,3 +44,25 @@ class Backend(object):
     @cachedproperty
     def Workdir(self):
         return self._import(self.module.workdir_class)
+
+    @property
+    def required_tools(self):
+        return self.module.required_tools
+
+    def missing_tools(self):
+        return [tool for tool in self.required_tools
+                if not py.path.local.sysfind(tool)]
+
+    @property
+    def required_modules(self):
+        return self.module.required_modules
+
+    def missing_modules(self):
+        def tryimport(name):
+            try:
+                return __import__(name)
+            except ImportError:
+                pass
+
+        return [module for module in self.required_modules
+                if not tryimport(module)]
