@@ -26,7 +26,6 @@ state_descriptions = dict(
 
 aliases = {
     'svn': 'subversion',
-    'bzr': 'bazaar',
     'hg': 'mercurial',
 }
 
@@ -35,40 +34,36 @@ aliases = {
 
 backends = {
     'mercurial': 'anyvc.mercurial',
-    'bazaar': 'anyvc.bazaar',
     'git': 'anyvc.git',
     'subversion': 'anyvc.subversion'
 }
 
-def get_backends(limit_to=None):
+def get_backends(limit_to=None,features=None):
     """
     :param limit_to: optional list of backends to try, will use all if use is none
     :type limit_to: list of string or None
 
     a generator over all known backends
     """
+    features = set(features or ())
     use = limit_to or backends
     for backend in use:
         try:
-            yield get_backend(backend)
-        except ImportError, e:
+            backend = get_backend(backend)
+            if backend.features.issuperset(features):
+                yield backend
+        except ImportError:
             pass
 
 
 def get_backend(vcs, use_remote=False):
     module = backends[vcs]
-    if use_remote is True:
-        use_remote = 'popen'
+
     if use_remote:
+        if use_remote is True:
+            use_remote = 'popen'
         from anyvc.remote import RemoteBackend
         return RemoteBackend(vcs, module, use_remote)
     else:
         from anyvc.backend import Backend
         return Backend(vcs, module)
-
-def get_wd_impl(vcs):
-    return get_backend(vcs).Workdir
-
-
-def get_repo_impl(vcs):
-    return get_backend(vcs).Repository
