@@ -5,7 +5,7 @@
     convience tool make execnet channels remote objects
 """
 import pickle
-
+from py.path import local
 
 class RemoteCaller(object):
     def __init__(self, channel):
@@ -13,6 +13,10 @@ class RemoteCaller(object):
 
     def _call_remote(self, name, *k, **kw):
         assert not self.channel.isclosed()
+
+        if 'path' in kw:
+            kw['path'] = str(kw['path'])
+
         data = (name, k, kw)
         self.channel.send(data)
         result = self.channel.receive()
@@ -36,6 +40,10 @@ class RemoteHandler(object):
     def _channel_callback(self, data):
         try:
             method, k, kw = data
+
+            if 'path' in kw:
+                kw['path'] = local(kw['path'])
+
             method = getattr(self, method)
             result = method(*k, **kw)
             self.channel.send(result)
