@@ -2,56 +2,59 @@
 # license lgpl3 or later
 
 from __future__ import with_statement
-import os
-import sys
 
 from anyvc.metadata import state_descriptions
-from functools import wraps, partial
-from os.path import join, dirname, exists
-from tempfile import mkdtemp
-from subprocess import call
-from shutil import rmtree
-from anyvc.metadata import get_backend
-from anyvc.remote import RemoteBackend
-
-def do(*args, **kw):
-    args = map(str, args)
-    print args
-    if 'cwd' in kw:
-        kw['cwd'] = str(kw['cwd'])
-    call(args, stdin=None, **kw)
-
 
 class WdWrap(object):
-    """wraps a vcs"""
-    def __init__(self, vc, path):
-        self.__path = path
-        self.__vc = vc
+    """
+    :param wd: the workdir to wrap
+    :type wd: subclass of :class:`anyvc.common.workdir.Workdir`
+
+    decorator for a vcs workdir instance
+    adds testing utility functions and proxies the other methods/attributes
+    to the real instance
+    """
+    def __init__(self, wd):
+        self.__wd = wd
 
     def __getattr__(self, name):
-        return getattr(self.__vc, name)
+        return getattr(self.__wd, name)
 
-    def bpath(self, name):
-        return self.__path.join(name)
 
     def put_files(self, mapping):
+        """
+        :type mapping: dict of (filename, text content)
+
+        the text content will be rstripped and get a newline appended
+        """
         for name, content in mapping.items():
-            path = self.__path.ensure(name)
+            path = self.path.ensure(name)
             path.write(content.rstrip() + '\n')
 
     def has_files(self, *files):
-        missing = [name for name in map(self.bpath, files) if not name.check()]
+        """
+        :arg files: a listing of filenames that shsould exist
+        """
+        missing = [name for name in map(self.path.join, files) if not name.check()]
         assert not missing, 'missing %s'%', '.join(missing)
         return not missing
 
     def delete_files(self, *relpaths):
+        """
+        :arg relpaths: listing of files to remove
+        """
         for path in relpaths:
-            self.bpath(path).remove()
+            self.path.join(path).remove()
 
     def check_states(self, exact=True, **kw):
-        """takes a mapping of filename-> state
-        if exact is true, additional states are ignored
-        returns true if all supplied files have the asumed state
+        """
+        .. better listing of the states!
+
+        :param bool exact: if true, ignore additional states
+        :keyword $statename: state name for that particular file list
+        :type $statename: list of relative path
+        :returns: True if all supplied files have the asumed state
+
         """
         __tracebackhide__ = True
         assert isinstance(exact, bool)
@@ -84,7 +87,10 @@ class WdWrap(object):
 
 
 class VcsMan(object):
-    """controller over a tempdir for tests"""
+    """
+    utility class to manage the creation of repositories and workdirs
+    inside of a specific path (usually the tmpdir funcarg of a test)
+    """
     def __init__(self, vc, base, xspec, backend):
         self.remote = xspec is not None
         self.vc = vc
@@ -95,36 +101,25 @@ class VcsMan(object):
     def __repr__(self): 
         return '<VcsMan %(vc)s %(base)r>'%vars(self)
 
-    def bpath(self, name):
-        return self.base.join(name)
-
     def create_wd(self, workdir, source=None):
-        path = self.bpath(workdir)
-        if source is None:
-            wd = self.backend.Workdir(path, create=True)
-            return WdWrap(wd, path)
-        else:
-            print source.path
+        """
+        :param workdir: name of the target workdir
+        :type workdir: str
+        :param source: name of a source repository
+        :type source: repo or None
 
-            path = getattr(source, 'path', source)
-            return self.make_wd(path, workdir)
+        create a workdir if `source` is given, use it as base
+        """
+        path = self.base/workdir
+        source_path = getattr(source, 'path', None)
+        wd = self.backend.Workdir(path, create=True, source=source_path)
+        return WdWrap(wd)
 
+    def make_repo(self, name):
+        """
+        :param name: name of the repository to create
 
+        create a repository using the given name
+        """
+        return self.backend.Repository(path=self.base/name, create=True)
 
-    def make_wd(self, repo, workdir):
-        path =self.bpath(workdir)
-        wd = self.backend.Workdir(path, create=True, source=repo)
-        return WdWrap(wd, path)
-
-    def make_repo(self, path):
-        return self.backend.Repository(
-                path=self.bpath(path),
-                create=True)
-
-    def make_wd_darcs(self, repo, workdir):
-        do('darcs', 'get', repo, workdir)
-        workdir.join('_darcs/prefs/author').write('test')
-
-    def make_repo_darcs(self, path):
-        path.ensure(dir=True)
-        do('darcs', 'initialize', '--darcs-2', cwd=path)
